@@ -4,7 +4,7 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,6 +26,7 @@
 #include "application.h"
 #include "atom.h"
 #include "bond.h"
+#include "brackets.h"
 #include "document.h"
 #include "electron.h"
 #include "fragment.h"
@@ -52,19 +53,15 @@
 #include "view.h"
 #include "window.h"
 #include "zoomdlg.h"
+#include <gcu/cmd-context.h>
 #include <gcu/filechooser.h>
 #include <gcu/loader.h>
 #include <gcu/loader-error.h>
 #include <glib/gi18n-lib.h>
-#include <openbabel/mol.h>
-#include <openbabel/reaction.h>
-#include <openbabel/obconversion.h>
-#include <clocale>
 #include <fstream>
 #include <cstring>
 #include <sys/stat.h>
 
-using namespace OpenBabel;
 using namespace std;
 using namespace gcu;
 
@@ -179,6 +176,50 @@ static void load_globs ()
 
 namespace gcp {
 
+// class ApplicationPrivate: implements useful callbacks
+class ApplicationPrivate {
+public:
+	static bool Init (Application *app);
+};
+
+bool ApplicationPrivate::Init (Application *app)
+{
+		// Check for programs
+		char *result = NULL, *errors = NULL;
+		// check for ghemical
+		app->m_HaveGhemical = (g_spawn_command_line_sync ("which ghemical", &result, &errors, NULL, NULL)
+			&& result && strlen (result));
+		if (result) {
+			g_free (result);
+			result = NULL;
+		}
+		if (errors) {
+			g_free (errors);
+			errors = NULL;
+		}
+		app->m_HaveGChem3D = (g_spawn_command_line_sync ("which gchem3d-"GCU_API_VER, &result, &errors, NULL, NULL)
+			&& result && strlen (result));
+		if (result) {
+			g_free (result);
+			result = NULL;
+		}
+		if (errors) {
+			g_free (errors);
+			errors = NULL;
+		}
+		app->m_HaveAvogadro = (g_spawn_command_line_sync ("which avogadro", &result, &errors, NULL, NULL)
+			&& result && strlen (result));
+		if (result) {
+			g_free (result);
+			result = NULL;
+		}
+		if (errors) {
+			g_free (errors);
+			errors = NULL;
+		}
+	return false;
+}
+
 // Objects creation static methods
 static Object* CreateAtom ()
 {
@@ -260,40 +301,35 @@ static Object* CreateElectron ()
 	return new Electron (NULL, false);
 }
 
+static Object* CreateBrackets ()
+{
+	return new Brackets ();
+}
+
 bool	Application::m_bInit = false;
-bool	Application::m_Have_Ghemical = false;
 bool	Application::m_Have_InChI = false;
+bool	Application::m_HaveGhemical = false;
+bool	Application::m_HaveGChem3D = false;
+bool	Application::m_HaveAvogadro = false;
 
 static void on_config_changed (GOConfNode *node, gchar const *key, Application *app)
 {
 	app->OnConfigChanged (node, key);
 }
 
-Application::Application ():
-	gcu::Application ("GChemPaint", DATADIR, "gchempaint", "gchempaint")
+Application::Application (CmdContext *cc):
+	gcu::Application ("GChemPaint", DATADIR, "gchempaint", "gchempaint", cc)
 {
 	m_CurZ = 6;
 	m_pActiveDoc = NULL;
 	m_pActiveTool = NULL;
+	m_pActiveTarget = NULL;
 	m_NumWindow = 1;
 
 	if (!m_bInit) {
 		/* Initialize plugins manager */
-		gcu::Loader::Init ();
-		// Check for programs
-		char *result = NULL, *errors = NULL;
-		// check for ghemical
-		m_Have_Ghemical = (g_spawn_command_line_sync ("which ghemical", &result, &errors, NULL, NULL)
-			&& result && strlen (result));
-		if (result) {
-			g_free (result);
-			result = NULL;
-		}
-		if (errors) {
-			g_free (errors);
-			errors = NULL;
-		}
-		OBConversion Conv;
+		gcu::Loader::Init (this);
+/*		OBConversion Conv;
 		m_Have_InChI = Conv.FindFormat ("inchi") != NULL || 
 			(g_spawn_command_line_sync ("which main_inchi", &result, &errors, NULL, NULL)
 			&& result && strlen (result));
@@ -302,47 +338,50 @@ Application::Application ():
 		if (errors) {
 			g_free (errors);
 			errors = NULL;
-		}
+		}*/
 
 		// Initialize types
-		Object::AddType ("atom", CreateAtom, AtomType);
-		Object::AddType ("bond", CreateBond, gcu::BondType);
-		Object::AddType ("molecule", CreateMolecule, MoleculeType);
-		Object::AddType ("reaction", CreateReaction, ReactionType);
-		Object::SetCreationLabel (ReactionType, _("Create a new reaction"));
-		ReactionStepType = Object::AddType ("reaction-step", CreateReactionStep);
-		Object::AddType ("reactant", CreateReactant, ReactantType);
-		Object::AddType ("reaction-arrow", CreateReactionArrow, ReactionArrowType);
-		ReactionPropType = Object::AddType ("reaction-prop", CreateReactionProp);
-		MesomerType = Object::AddType ("mesomer", CreateMesomer);
-		Object::AddType ("mesomery", CreateMesomery, MesomeryType);
-		Object::SetCreationLabel (MesomeryType, _("Create a new mesomery relationship"));
-		Object::AddType ("mesomery-arrow", CreateMesomeryArrow, MesomeryArrowType);
-		Object::AddType ("text", CreateText, TextType);
-		Object::AddType ("fragment", CreateFragment, FragmentType);
-		ElectronType = Object::AddType ("electron", CreateElectron);
+		AddType ("atom", CreateAtom, AtomType);
+		AddType ("bond", CreateBond, gcu::BondType);
+		AddType ("molecule", CreateMolecule, MoleculeType);
+		AddType ("reaction", CreateReaction, ReactionType);
+		SetCreationLabel (ReactionType, _("Create a new reaction"));
+		ReactionStepType = AddType ("reaction-step", CreateReactionStep);
+		AddType ("reactant", CreateReactant, ReactantType);
+		AddType ("reaction-arrow", CreateReactionArrow, ReactionArrowType);
+		AddType ("reaction-operator", NULL, ReactionOperatorType);
+		ReactionPropType = AddType ("reaction-prop", CreateReactionProp);
+		MesomerType = AddType ("mesomer", CreateMesomer);
+		AddType ("mesomery", CreateMesomery, MesomeryType);
+		SetCreationLabel (MesomeryType, _("Create a new mesomery relationship"));
+		AddType ("mesomery-arrow", CreateMesomeryArrow, MesomeryArrowType);
+		AddType ("text", CreateText, TextType);
+		AddType ("fragment", CreateFragment, FragmentType);
+		ElectronType = AddType ("electron", CreateElectron);
 		Object::AddAlias (ElectronType, "electron-pair");
+		BracketsType = AddType ("brackets", CreateBrackets);
 		// Add rules
-		Object::AddRule ("reaction", RuleMustContain, "reaction-step");
-		Object::AddRule ("reaction-step", RuleMustContain, "reactant");
-		Object::AddRule ("reactant", RuleMustBeIn, "reaction-step");
-		Object::AddRule ("reaction-step", RuleMustBeIn, "reaction");
-		Object::AddRule ("reaction", RuleMustContain, "reaction-arrow");
-		Object::AddRule ("reaction-arrow", RuleMustBeIn, "reaction");
-		Object::AddRule ("reaction-arrow", RuleMayContain, "reaction-prop");
-		Object::AddRule ("reaction-prop", RuleMustBeIn, "reaction-arrow");
-		Object::AddRule ("reaction-prop", RuleMayContain, "molecule");
-		Object::AddRule ("reaction-prop", RuleMayContain, "text");
-		Object::AddRule ("reactant", RuleMayContain, "molecule");
-		Object::AddRule ("mesomer", RuleMustContain, "molecule");
-		Object::AddRule ("mesomer", RuleMustBeIn, "mesomery");
-		Object::AddRule ("mesomery", RuleMustContain, "mesomer");
-		Object::AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
-		Object::AddRule ("mesomery-arrow", RuleMustBeIn, "mesomery");
-		MechanismArrowType = Object::AddType ("mechanism-arrow", CreateMechanismArrow);
-		MechanismStepType = Object::AddType ("mechanism-step", CreateMechanismStep);
-		Object::AddRule ("reaction-step", RuleMayContain, "mechanism-step");
-		Object::AddRule ("mesomery", RuleMayContain, "mechanism-step");
+		AddRule ("reaction", RuleMustContain, "reaction-step");
+		AddRule ("reaction-step", RuleMustContain, "reactant");
+		AddRule ("reactant", RuleMustBeIn, "reaction-step");
+		AddRule ("reaction-step", RuleMustBeIn, "reaction");
+		AddRule ("reaction", RuleMustContain, "reaction-arrow");
+		AddRule ("reaction-arrow", RuleMustBeIn, "reaction");
+		AddRule ("reaction-arrow", RuleMayContain, "reaction-prop");
+		AddRule ("reaction-prop", RuleMustBeIn, "reaction-arrow");
+		AddRule ("reaction-prop", RuleMayContain, "molecule");
+		AddRule ("reaction-prop", RuleMayContain, "text");
+		AddRule ("reaction-operator", RuleMustBeIn, "reaction-step");
+		AddRule ("reactant", RuleMayContain, "molecule");
+		AddRule ("mesomer", RuleMustContain, "molecule");
+		AddRule ("mesomer", RuleMustBeIn, "mesomery");
+		AddRule ("mesomery", RuleMustContain, "mesomer");
+		AddRule ("mesomery", RuleMustContain, "mesomery-arrow");
+		AddRule ("mesomery-arrow", RuleMustBeIn, "mesomery");
+		MechanismArrowType = AddType ("mechanism-arrow", CreateMechanismArrow);
+		MechanismStepType = AddType ("mechanism-step", CreateMechanismStep);
+		AddRule ("reaction-step", RuleMayContain, "mechanism-step");
+		AddRule ("mesomery", RuleMayContain, "mechanism-step");
 
 		// Create global signal ids
 		OnChangedSignal = Object::CreateNewSignalId ();
@@ -368,6 +407,7 @@ Application::Application ():
 		// load plugins
 		Plugin::LoadPlugins ();
 		m_bInit = true;
+		g_idle_add (reinterpret_cast <GSourceFunc> (ApplicationPrivate::Init), this); 
 	}
 	RadioActions = NULL;
 	m_entries = 0;
@@ -459,8 +499,6 @@ Application::~Application ()
 	if (m_entries)
 		g_free (RadioActions);
 	g_object_unref (IconFactory);
-	// unload plugins
-	Plugin::UnloadPlugins ();
 }
 
 void Application::ActivateTool (const string& toolname, bool activate)
@@ -519,25 +557,22 @@ enum {
 	PIXBUF
 };
 
-bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, GtkWindow *window, gcu::Document *Doc)
+bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, G_GNUC_UNUSED GtkWindow *window, gcu::Document *Doc)
 {
 	const gchar* ext;
 	Document *pDoc = static_cast<Document*> (Doc);
-	if (!filename || !strlen(filename) || filename[strlen(filename) - 1] == '/')
-	{
-		GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-															_("Please enter a file name,\nnot a directory"));
-		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
-		gtk_dialog_run (GTK_DIALOG (message));
-		gtk_widget_destroy (message);
+	if (!filename || !strlen (filename) || g_file_test (filename, G_FILE_TEST_IS_DIR)) {
+		GetCmdContext ()->Message (_("Please enter a file name,\nnot a directory"), CmdContext::SeverityWarning, true);
 		return true;
 	}
 	int file_type = -1;
 	int n = strlen (filename), i = n - 1;
 	char const *pixbuf_type = NULL;
 	string filename2 = filename;
-	while ((i > 0) && (filename[i] != '.') && (filename[i] != '/')) i--;
-	if (filename[i] == '/') i = 0;
+	while ((i > 0) && (filename[i] != '.') && (filename[i] != '/'))
+		i--;
+	if (filename[i] == '/')
+		i = 0;
 	ext = (i > 0)? filename + i + 1: NULL;
 	if (!mime_type) // to be really sure we don't crash
 		mime_type = "application/x-gchempaint";
@@ -571,11 +606,8 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 		char *unescaped = g_uri_unescape_string (filename, NULL);
 		char *mess = g_strdup_printf (_("Sorry, format %s not supported!\nFailed to load %s."), mime_type, unescaped);
 		g_free (unescaped);
-		GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-													"%s", mess);
-		gtk_dialog_run (GTK_DIALOG (message));
+		GetCmdContext ()->Message (mess, CmdContext::SeverityError, true);
 		g_free (mess);
-		gtk_widget_destroy (message);
 		return true;
 	}
 	list<string> &exts = globs[mime_type];
@@ -597,31 +629,25 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				filename2 += string(".") + default_ext;
 		file = g_file_new_for_uri (filename2.c_str ());
 		err = g_file_query_exists (file, NULL);
-		gint result = GTK_RESPONSE_YES;
+		CmdContext::Response result = CmdContext::ResponseYes;
 		if (err) {
 			char *unescaped = g_uri_unescape_string (filename2.c_str (), NULL);
 			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
 			g_free (unescaped);
-			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", message));
-			gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
-			result = gtk_dialog_run (Box);
-			gtk_widget_destroy (GTK_WIDGET (Box));
+			result = GetCmdContext ()->GetResponse (message, CmdContext::ResponseYes | CmdContext::ResponseNo);
 			g_free (message);
 		}
-		if (result == GTK_RESPONSE_YES) {
+		if (result == CmdContext::ResponseYes) {
 			// destroy the old file if needed
 			if (err) {
 				GError *error = NULL;
 				g_file_delete (file, NULL, &error);
 				if (error) {
 					char *unescaped = g_uri_unescape_string (filename2.c_str (), NULL);
-					gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), unescaped, error->message);
+					gchar *message = g_strdup_printf (_("Error while processing %s:\n%s"), unescaped, error->message);
 					g_free (unescaped);
 					g_error_free (error);
-					GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", message));
-					gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
-					result = gtk_dialog_run (Box);
-					gtk_widget_destroy (GTK_WIDGET (Box));
+					GetCmdContext ()->Message (message, CmdContext::SeverityError, false);
 					g_free (message);
 					g_object_unref (file);
 					return false;
@@ -644,11 +670,10 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 				m_pActiveDoc->ExportImage (filename2, pixbuf_type, GetImageResolution ());
 				break;
 			default:
-				if (Save (filename2, mime_type, pDoc, ContentType2D));
-				else if (!strcmp (mime_type, "application/x-gchempaint"))
+				if (!strcmp (mime_type, "application/x-gchempaint"))
 					SaveGcp (filename2, pDoc);
 				else
-					SaveWithBabel (filename2, mime_type, pDoc);
+					Save (filename2, mime_type, pDoc, ContentType2D);
 			}
 		}
 		g_object_unref (file);
@@ -679,54 +704,48 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			pDoc = m_pActiveDoc;
 		}
 		pDoc->SetFileName(filename2, mime_type);
-		ContentType type = Load (filename2, mime_type, pDoc);
-		if (type != ContentTypeUnknown) {
-			switch (type) {
-			case ContentType3D: {
-				// open in gchem3d instead
-				string command = string ("gchem3d-") + API_VERSION + " " + filename2;
-				g_spawn_command_line_async (command.c_str (), NULL);
-				if (create) {
-					pDoc->GetWindow ()->Destroy ();
-					pDoc = NULL;
-					} else
-					pDoc->Clear ();
-				return false;
-			}
-			case ContentTypeCrystal:
-				break;
-			case ContentTypeSpectrum:
-				break;
-			default: {
-				pDoc->Loaded ();
-				double l = pDoc->GetMedianBondLength ();
-				if (l > 0.) {
-					double r = pDoc->GetBondLength () / l;
-					if (fabs (r - 1.) > .1) { // might not work properly in some rare cases when there are a lot of short or long bonds
-						Matrix2D m (r, 0., 0., r);
-						// FIXME: this would not work for reactions
-						pDoc->Transform2D (m, 0., 0.);
-					}
+		if (!strcmp (mime_type, "application/x-gchempaint"))
+			OpenGcp (filename2, pDoc);
+		else {
+			// FIXME: rewrite this code
+			ContentType type = Load (filename2, mime_type, pDoc);
+			if (type != ContentTypeUnknown) {
+				switch (type) {
+				case ContentType3D: {
+					// open in gchem3d instead
+					string command = string ("gchem3d-") + API_VERSION + " " + filename2;
+					g_spawn_command_line_async (command.c_str (), NULL);
+					if (create) {
+						pDoc->GetWindow ()->Destroy ();
+						pDoc = NULL;
+						} else
+						pDoc->Clear ();
+					return false;
 				}
-				break;
+				case ContentTypeCrystal:
+					break;
+				case ContentTypeSpectrum:
+					break;
+				default: {
+					pDoc->Loaded ();
+					double l = pDoc->GetMedianBondLength ();
+					if (l > 0.) {
+						double r = pDoc->GetBondLength () / l;
+						if (fabs (r - 1.) > .1) { // might not work properly in some rare cases when there are a lot of short or long bonds
+							Matrix2D m (r, 0., 0., r);
+							// FIXME: this would not work for reactions
+							pDoc->Transform2D (m, 0., 0.);
+						}
+					}
+					break;
+				}
+				};
+				pDoc->GetView ()->AddObject (pDoc);
+				pDoc->GetView ()->Update (pDoc);
+				pDoc->GetView ()->EnsureSize ();
+				if (pDoc->GetWindow ())
+					pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", pDoc->HasChildren ());
 			}
-			};
-			pDoc->GetView ()->AddObject (pDoc);
-			pDoc->GetView ()->Update (pDoc);
-			pDoc->GetView ()->EnsureSize ();
-			if (pDoc->GetWindow ())
-				pDoc->GetWindow ()->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", pDoc->HasChildren ());
-		} else {
-			if (create) {
-				pDoc->GetWindow ()->Destroy ();
-				pDoc = NULL;
-				while (gdk_events_pending ())
-					gtk_main_iteration ();
-			}
-			if (!strcmp (mime_type, "application/x-gchempaint"))
-				OpenGcp (filename2, pDoc);
-			else
-				OpenWithBabel (filename2, mime_type, pDoc);
 		}
 	}
 	catch (LoaderError &e) {
@@ -739,158 +758,12 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 		// Note to translator: add a space if needed before the semicolon
 		mess += _(":\n");
 		mess += e.what ();
-		GtkWidget *message = gtk_message_dialog_new (NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess.c_str (), NULL, NULL);
+		GetCmdContext ()->Message (mess.c_str (), CmdContext::SeverityError, false);
 		g_free (unescaped);
-		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
-		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
-		gtk_widget_show (message);
 	}
 	return false;
 }
 
-void Application::SaveWithBabel (string const &filename, const gchar *mime_type, Document* pDoc)
-{
-	pDoc->SetFileName (filename, mime_type);
-	pDoc->Save ();
-	GtkRecentData data;
-	data.display_name = (char*) pDoc->GetTitle ();
-	data.description = NULL;
-	data.mime_type = (char*) mime_type;
-	data.app_name = const_cast<char*> ("gchempaint");
-	data.app_exec = const_cast<char*> ("gchempaint %u");
-	data.groups = NULL;
-	data.is_private =  FALSE;
-	gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
-}
-
-void Application::OpenWithBabel (string const &filename, const gchar *mime_type, Document* pDoc)
-{
-	string old_num_locale;
-	bool bNew = (pDoc == NULL || !pDoc->GetEmpty () || pDoc->GetDirty ());
-	GFile *file;
-	GFileInfo *info = NULL;
-	GError *error = NULL;
-	bool result = true, read_only = false;
-	gsize size = 0;
-	try {
-		if (!filename.length ())
-			throw (int) 0;
-		file = g_file_new_for_uri (filename.c_str ());
-		info = g_file_query_info (file,
-								  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE","G_FILE_ATTRIBUTE_STANDARD_SIZE,
-								  G_FILE_QUERY_INFO_NONE, NULL, &error);
-		if (error) {
-			g_warning ("GIO error: %s", error->message);
-			g_error_free (error);
-			if (info)
-				g_object_unref (info);
-			g_object_unref (file);
-			return;
-		}
-		size = g_file_info_get_size (info);
-		read_only = !g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE);
-		g_object_unref (info);
-		if (bNew) {
-			OnFileNew ();
-			pDoc = m_pActiveDoc;
-		}
-		char *buf = new char[size + 1];
-		GInputStream *input = G_INPUT_STREAM (g_file_read (file, NULL, &error));
-		gsize n = 0;
-		while (n < size) {
-			n += g_input_stream_read (input, buf, size, NULL, &error);
-			if (error) {
-				g_message ("GIO could not read the file: %s", error->message);
-				g_error_free (error);
-				delete [] buf;
-				g_object_unref (input);
-				g_object_unref (file);
-				return;
-			}
-		}
-		g_object_unref (input);
-		g_object_unref (file);
-		buf[size] = 0;
-		istringstream iss (buf);
-		old_num_locale = setlocale (LC_NUMERIC, NULL);
-		setlocale(LC_NUMERIC, "C");
-		OBMol Mol;
-		OBConversion Conv;
-		OBFormat* pInFormat = Conv.FormatFromExt (filename.c_str ());
-		if (pInFormat == NULL) {
-			delete [] buf;
-			throw 1;
-		}
-		Conv.SetInFormat (pInFormat);
-		while (!iss.eof () && Conv.Read (&Mol, &iss)) {
-			result = pDoc->ImportOB(Mol);
-			Mol.Clear ();
-			if (!result)
-				break;
-		}
-		setlocale (LC_NUMERIC, old_num_locale.c_str ());
-		delete [] buf;
-		if (!result)
-		{
-			if (bNew)
-				pDoc->GetWindow ()->Destroy ();
-			throw (int) 2;
-		}
-		pDoc->SetFileName (filename, mime_type);
-		pDoc->SetReadOnly (read_only);
-		double l = pDoc->GetMedianBondLength ();
-		if (l > 0.) {
-			double r = pDoc->GetBondLength () / l;
-			if (fabs (r - 1.) > .0001) { 
-				Matrix2D m (r, 0., 0., r);
-				// FIXME: this would not work for reactions
-				pDoc->Transform2D (m, 0., 0.);
-			}
-		}
-		View *pView = pDoc->GetView ();
-		pView->Update (pDoc);
-		pDoc->Update ();
-		pView->EnsureSize ();
-		Window *win = pDoc->GetWindow ();
-		if (win)
-			win->SetTitle (pDoc->GetTitle ());
-		GtkRecentData data;
-		data.display_name = (char*) pDoc->GetTitle ();
-		data.description = NULL;
-		data.mime_type = (char*) mime_type;
-		data.app_name = const_cast<char*> ("gchempaint");
-		data.app_exec = const_cast<char*> ("gchempaint %u");
-		data.groups = NULL;
-		data.is_private =  FALSE;
-		gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
-	}
-	catch (int num)
-	{
-		gchar *mess = NULL;
-		GtkWidget* message;
-		switch (num)
-		{
-		case 0:
-			mess = _("No filename");
-			break;
-		case 1:
-			mess = _("Could not open file\n%s");
-			break;
-		case 2:
-			mess = _("%s: parse error.");
-			break;
-		default:
-			throw (num); //this should not occur
-		}
-		char *unescaped = g_uri_unescape_string (filename.c_str (), NULL);
-		message = gtk_message_dialog_new (NULL, (GtkDialogFlags) 0, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, mess, unescaped, NULL);
-		g_free (unescaped);
-		gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
-		g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
-		gtk_widget_show(message);
-	}
-}
-
 void Application::SaveGcp (string const &filename, Document* pDoc)
 {
 	pDoc->SetFileName (filename, "application/x-gchempaint");
@@ -920,7 +793,6 @@ static int	cb_vfs_to_xml (GInputStream *input, char* buf, int nb)
 void Application::OpenGcp (string const &filename, Document* pDoc)
 {
 	xmlDocPtr xml = NULL;
-	char *old_num_locale, *old_time_locale;
 	GError *error = NULL;
 	GFileInfo *info = NULL;
 	bool create = false;
@@ -959,10 +831,6 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 			throw (int) 2;
 		if (strcmp((char*)xml->children->name, "chemistry"))
 			throw (int) 3;	//FIXME: that could change when a dtd is available
-		old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
-		setlocale(LC_NUMERIC, "C");
-		old_time_locale = g_strdup(setlocale(LC_TIME, NULL));
-		setlocale(LC_TIME, "C");
 		if (!pDoc || !pDoc->GetEmpty () || pDoc->GetDirty ()) {
 			create = true;
 			OnFileNew ();
@@ -970,10 +838,6 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 		}
 		pDoc->SetFileName(filename, "application/x-gchempaint");
 		bool result = pDoc->Load(xml->children);
-		setlocale(LC_NUMERIC, old_num_locale);
-		g_free(old_num_locale);
-		setlocale(LC_TIME, old_time_locale);
-		g_free(old_time_locale);
 		if (!result) {
 			if (create)
 				pDoc->GetWindow ()->Destroy ();
@@ -1294,12 +1158,12 @@ void Application::AddMimeType (list<string> &l, string const& mime_type)
 
 void Application::TestSupportedType (char const *mime_type)
 {
-	OBFormat *f = OBConversion::FormatFromMIME (mime_type);
+/*	OBFormat *f = OBConversion::FormatFromMIME (mime_type);
 	if (f != NULL) {
 		AddMimeType (m_SupportedMimeTypes, mime_type);
 		if (!(f->Flags () & NOTWRITABLE))
 			AddMimeType (m_WriteableMimeTypes, mime_type);
-	}
+	}*/
 }
 
 list<string> &Application::GetExtensions(string &mime_type)
