@@ -69,9 +69,17 @@ class Tool;
 class Document;
 typedef void (*BuildMenuCb) (GtkUIManager *UIManager);
 
+/*!
+@brief Cursors.
+
+Enumerates known cursors.
+*/
 typedef enum {
+/*!Cursor used when a click would have no effect.*/
 	CursorUnallowed,
+/*!Cursor used when a click would start drawing operation.*/
 	CursorPencil,
+/*!Maximum value, does not correspond to a valid cursor.*/
 	CursorMax
 } CursorId;
 
@@ -83,11 +91,12 @@ It is a virtual class since at least one method is pure virtual (gcp::Applicatio
 */
 class Application: public gcu::Application
 {
+friend class ApplicationPrivate;
 public:
 /*!
 The default constructor.
 */
-	Application ();
+	Application (gcu::CmdContext *cc = NULL);
 /*!
 The destructor.
 */
@@ -204,22 +213,6 @@ chooser to process the file.
 	bool FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, GtkWindow *window, gcu::Document *pDoc = NULL);
 /*!
 @param filename the URI of the file to save.
-@param mime_type the mime type.
-@param pDoc the document to save.
-
-Saves the active document using the Openbabel library.
-*/
-	void SaveWithBabel (std::string const &filename, const gchar *mime_type, gcp::Document* pDoc);
-/*!
-@param filename the URI of the file to load.
-@param mime_type the mime type.
-@param pDoc a document or NULL.
-
-Loads a document using the Openbabel library.
-*/
-	void OpenWithBabel (std::string const &filename, const gchar *mime_type, gcp::Document* pDoc);
-/*!
-@param filename the URI of the file to save.
 @param pDoc the document to save.
 
 Saves the active document in the native GChemPaint format.
@@ -242,10 +235,6 @@ Saves the active view as an image.
 */
 	void OnSaveAsImage ();
 /*!
-@return true if ghemical is usable.
-*/
-	bool HaveGhemical () {return m_Have_Ghemical;}
-/*!
 @return true if InChIs can be evaluated for molecules.
 */
 	bool HaveInChI () {return m_Have_InChI;}
@@ -407,8 +396,15 @@ it is pure virtual.
 */
 	virtual void OnFileNew (char const *Theme = NULL) = 0;
 
+/*!
+@param id a CursorId
+
+@return the corresponding GdkCursor if any.
+*/
 	GdkCursor *GetCursor (CursorId id)  {return m_Cursors[id];}
 
+	bool Have3DSupport () {return m_HaveGhemical | m_HaveGChem3D | m_HaveAvogadro;}
+
 protected:
 /*!
 Initialize the tools box so that the selection tool is active. This method is
@@ -453,7 +449,6 @@ private:
 	std::map <std::string, Tool*> m_Tools;
 	Tool* m_pActiveTool;
 	static bool m_bInit;
-	static bool m_Have_Ghemical;
 	static bool m_Have_InChI;
 	xmlDocPtr XmlDoc;
 	GtkIconFactory *IconFactory;
@@ -472,7 +467,16 @@ private:
 	std::list<BuildMenuCb> m_MenuCbs;
 	GdkCursor *m_Cursors[CursorMax];
 
-GCU_RO_POINTER_PROP	(GtkStyle, Style)
+/*!\fn GetStyle()
+@return the default GtkStyle for the windows.
+*/
+	GCU_RO_POINTER_PROP	(GtkStyle, Style)
+/*!\fn GetHaveGhemical
+@return true if ghemical is usable on startup.
+*/
+	GCU_RO_STATIC_PROP (bool, HaveGhemical);
+	GCU_RO_STATIC_PROP (bool, HaveGChem3D);
+	GCU_RO_STATIC_PROP (bool, HaveAvogadro);
 };
 
 }	// namespace gcp
