@@ -4,7 +4,7 @@
  * GChemPaint library
  * atom.h 
  *
- * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -34,11 +34,6 @@
 #include <gcu/element.h>
 #include <gcu/macros.h>
 
-namespace OpenBabel
-{
-	class OBAtom;
-}
-
 /*!\file*/
 namespace gcp {
 
@@ -127,13 +122,6 @@ Default construtor.
 */
 	Atom (int Z, double x, double y, double z);
 /*!
-@param atom an OpenBabel Atom instance.
-
-Builds an atom importing as many properties from an existing OpenBabel
-Atom instance.
-*/
-	Atom (OpenBabel::OBAtom* atom);
-/*!
 The destructor.
 */
 	virtual ~Atom ();
