@@ -28,6 +28,7 @@
 #include "fragment.h"
 #include "settings.h"
 #include "document.h"
+#include "molecule.h"
 #include "theme.h"
 #include "view.h"
 #include "widgetdata.h"
@@ -520,7 +521,7 @@ void Bond::Revert ()
 
 void Bond::SetSelected (int state)
 {
-	if (!m_order)
+	if (!m_order || !m_Item)
 		return;
 	GOColor color;
 	switch (state) {	
@@ -569,7 +570,7 @@ void Bond::SetSelected (int state)
 
 void Bond::AddItem ()
 {
-	if (m_Item)
+	if (m_Item || !m_Begin || !m_End)
 		return;
 	double x1, y1, x2, y2;
 	Document *doc = static_cast <Document*> (GetDocument ());
@@ -688,6 +689,8 @@ void Bond::UpdateItem ()
 double Bond::GetYAlign ()
 {
 	double x1, y1, x2, y2;
+	if (!m_Begin || !m_End)
+		return 0.;
 	m_Begin->GetCoords(&x1, &y1);
 	m_End->GetCoords (&x2, &y2);
 	return (y1 + y2) / 2;
@@ -947,4 +950,14 @@ void Bond::AdjustPosition (double &x, double &y)
 	y += (y - y2) / d;
 }
 
+void Bond::OnLoaded ()
+{
+	gcu::Bond::OnLoaded ();
+	if (m_Begin && m_End && GetParent ()->GetType () != MoleculeType) {
+		Object *obj = new Molecule (static_cast <gcp::Atom *> (m_Begin));
+		obj->SetDirty ();
+	} else
+		GetParent ()->SetDirty ();
+}
+
 }	//	namespace gcp
