@@ -4,7 +4,7 @@
  * GChemPaint library
  * reactant.cc 
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -157,7 +157,11 @@ bool Reactant::Load (xmlNodePtr node)
 		child = child->next;
 	}
 	Lock (false);
-	return (Child != NULL);
+	if (Child != NULL) {
+		pDoc->ObjectLoaded (this);
+		return true;
+	} else
+		return false;
 }
 
 double Reactant::GetYAlign ()
@@ -173,6 +177,8 @@ void Reactant::AddStoichiometry ()
 	Theme *pTheme= pDoc->GetTheme ();
 	WidgetData *pData = (WidgetData*) g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data");
 	gccv::Rect rect;
+	Operation *op = pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
+	op->AddNode (GetGroup ()->Save (pXmlDoc), 0);
 	pData->GetObjectBounds (this, &rect);
 	double x = rect.x0 / pTheme->GetZoomFactor ();
 	Text *text = new Text (x, GetYAlign ());
@@ -196,7 +202,7 @@ bool Reactant::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Obj)
 		gccv::Rect rect;
 		unsigned n = GetChildrenNumber ();
 		map<string, Object*>::iterator i;
-		Object *pObj;
+		Object *pObj, *parent = GetParent ();
 		if (n == 0)
 			delete this;
 		else if (n == 1) {
@@ -209,7 +215,9 @@ bool Reactant::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Obj)
 					pDoc->Remove (Stoichiometry);
 					delete this;
 				}
-			}
+			} else if (GetFirstChild (i) != Child)
+				Child = (*i).second;
+			parent->EmitSignal (OnChangedSignal);
 		} else if ((n == 2) && Stoichiometry) {
 			// Just need to space the two children
 			pData->GetObjectBounds (Stoichiometry, &rect);
@@ -258,4 +266,9 @@ bool Reactant::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Obj)
 	return true;
 }
 
+std::string Reactant::Name ()
+{
+	return _("Reactant");
+}
+
 }	//	namespace gcp
