@@ -145,6 +145,10 @@ bool Tool::Activate (bool bState)
 		return true;
 	} else {
 		if (Deactivate ()) {
+			if (m_Item) {
+				delete m_Item;
+				m_Item = NULL;
+			}
 			if (GTK_IS_WIDGET (m_pWidget))
 				gdk_window_set_cursor (gtk_widget_get_parent_window (m_pWidget), NULL);
 			m_pObject = NULL;
