@@ -24,13 +24,18 @@
 
 #include "config.h"
 #include "bracketstool.h"
+#include "group.h"
 #include <gcu/message.h>
 #include <gcu/ui-builder.h>
 #include <gcp/application.h>
 #include <gcp/atom.h>
+#include <gcp/brackets.h>
 #include <gcp/bond.h>
 #include <gcp/document.h>
+#include <gcp/fontsel.h>
 #include <gcp/fragment.h>
+#include <gcp/mechanism-step.h>
+#include <gcp/reaction-step.h>
 #include <gcp/settings.h>
 #include <gcp/theme.h>
 #include <gcp/view.h>
@@ -64,7 +69,6 @@ void gcpBracketsTool::OnDrag ()
 	} else {
 		m_Item = new gccv::Rectangle (m_pView->GetCanvas (), m_x0, m_y0, m_x - m_x0, m_y - m_y0);
 		gcp::Theme *theme = m_pView->GetDoc ()->GetTheme ();
-		static_cast <gccv::LineItem *> (m_Item)->SetLineColor (gcp::SelectColor);
 		static_cast <gccv::LineItem *> (m_Item)->SetLineWidth (theme->GetBondWidth ());
 		static_cast <gccv::FillItem *> (m_Item)->SetFillColor (0);
 	}
@@ -125,10 +129,17 @@ void gcpBracketsTool::OnDrag ()
 		if ((*i)->CanSelect ())
 			m_pData->SetSelected (*i);
 	m_pData->SimplifySelection ();
+	if (Evaluate ())
+		static_cast <gccv::LineItem *> (m_Item)->SetLineColor (gcp::AddColor);
+	else
+		static_cast <gccv::LineItem *> (m_Item)->SetLineColor (gcp::DeleteColor);
 }
 
 void gcpBracketsTool::OnRelease ()
 {
+	if (Evaluate ()) {
+	}
+	m_pData->UnselectAll ();
 }
 
 GtkWidget *gcpBracketsTool::GetPropertyPage ()
@@ -142,6 +153,11 @@ GtkWidget *gcpBracketsTool::GetPropertyPage ()
 		box = builder->GetComboBox ("used-box");
 		gtk_combo_box_set_active (box, m_Used);
 		g_signal_connect (box, "changed", G_CALLBACK (gcpBracketsTool::OnUsedChanged), this);
+		GtkBox *fbox = GTK_BOX (builder->GetWidget ("font-box"));
+		GtkWidget *widget = GTK_WIDGET (g_object_new (GCP_TYPE_FONT_SEL, "allow-slanted", false, "label", "{[()]}", NULL));
+		gtk_box_pack_start (fbox, widget, false, true, 0);
+		gtk_widget_show_all (widget);
+		m_FontSel = reinterpret_cast <GcpFontSel *> (widget);
 
 		GtkWidget *res = builder->GetRefdWidget ("brackets");
 		delete builder;
@@ -171,3 +187,45 @@ void gcpBracketsTool::OnUsedChanged (GtkComboBox *box, gcpBracketsTool *tool)
 {
 	tool->m_Used = static_cast <gcpBracketsUsed> (gtk_combo_box_get_active (box));
 }
+
+void gcpBracketsTool::Activate ()
+{
+	gcp::Theme *theme = m_pApp->GetActiveDocument ()->GetTheme ();
+	g_object_set (G_OBJECT (m_FontSel),
+					"family", theme->GetTextFontFamily (),
+					"weight", theme->GetTextFontWeight (),
+					"variant", theme->GetTextFontVariant (),
+					"stretch", theme->GetTextFontStretch (),
+					"size", theme->GetTextFontSize (),
+					NULL);
+}
+
+bool gcpBracketsTool::Evaluate ()
+{
+	gcu::Object *obj;
+	if (m_pData->SelectedObjects.size () == 0)
+		return false;
+	std::set <gcu::TypeId> const &rules = m_pApp->GetRules (gcp::BracketsType, gcu::RuleMayContain);
+	if (m_pData->SelectedObjects.size () == 1) {
+		obj = m_pData->SelectedObjects.front ();
+		gcu::TypeId type = obj->GetType ();
+		if (type == gcu::MoleculeType || type == gcp::ReactionStepType ||
+		    type == gcp::MechanismStepType || type == gcu::MesomeryType ||
+		    rules.find (type) != rules.end ()) {
+			// Evaluate bounds
+			m_pData->GetObjectBounds (obj, &m_ActualBounds);
+			return true;
+		}
+	}
+	std::list <gcu::Object*>::iterator i = m_pData->SelectedObjects.begin (),
+									   end = m_pData->SelectedObjects.end ();
+	gcu::Object *molecule = (*i)->GetMolecule ();
+	if (molecule != NULL) {
+		for (i++; i != end; i++)
+			if ((*i)->GetMolecule () != molecule)
+				goto not_a_molecule;
+		// now we need to test whether all selected atoms are connected (is this true?)
+	}
+not_a_molecule:
+	return false;
+}
