@@ -4,7 +4,7 @@
  * GChemPaint selection plugin
  * plugin.cc 
  *
- * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,6 +25,7 @@
 #include "config.h"
 #include "plugin.h"
 #include <gcp/application.h>
+#include <gcp/brackets.h>
 #include <gcp/molecule.h>
 #include "selectiontool.h"
 #include "lassotool.h"
@@ -100,4 +101,5 @@ void gcpSelectionPlugin::Populate (gcp::Application* App)
 	new gcpEraserTool (App);
 	new gcpBracketsTool (App);
 	App->ActivateTool ("Select", true);
+	App->AddRule (gcp::BracketsType, gcu::RuleMayContain, GroupType);
 }
