@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/calc/gchemcalc.cc 
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -53,6 +53,7 @@ class GChemCalc: public Application, public Printable
 {
 public:
 	GChemCalc ();
+	~GChemCalc ();
 	Formula formula;
 	GtkLabel *markup, *raw, *weight, *mono, *monomass;
 	GtkWidget *graph_widget;
@@ -102,11 +103,11 @@ GChemCalc::GChemCalc ():
 	Application ("gchemcalc"),
 	formula ("")
 {
-	Object::AddType ("atom", CreateAtom, AtomType);
-	Object::AddType ("pseudo-atom", CreateAtom);
-	Object::AddType ("bond", CreateBond, BondType);
-	Object::AddType ("molecule", CreateMolecule, MoleculeType);
-	Object::AddType ("document", CreateDocument, DocumentType);
+	AddType ("atom", CreateAtom, AtomType);
+	AddType ("pseudo-atom", CreateAtom);
+	AddType ("bond", CreateBond, BondType);
+	AddType ("molecule", CreateMolecule, MoleculeType);
+	AddType ("document", CreateDocument, DocumentType);
 	// Load residues
 	xmlDocPtr doc;
 	char *name;
@@ -125,13 +126,18 @@ GChemCalc::GChemCalc ():
 	g_free (name);
 }
 
+GChemCalc::~GChemCalc ()
+{
+	g_object_unref (m_UIManager);
+}
+
 void GChemCalc::ParseNodes (xmlNodePtr node)
 {
 	Residue* r;
 	while (node) {
 		if (!strcmp ((char*) node->name, "residue")) {
 			r = new Residue ();
-			r->Load (node);
+			r->Load (node, this);
 		}
 		node = node->next;
 	}
@@ -279,7 +285,7 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 	const gchar * authors[] = {"Jean Bréfort", NULL};
 	const gchar * comments = _("GChemCalc is a simple calculator for chemists");
 	/* const gchar * documentors[] = {NULL}; */
-	const gchar * copyright = _("Copyright © 2005-2008 Jean Bréfort");
+	const gchar * copyright = _("Copyright © 2005-2010 Jean Bréfort");
 	const gchar * license =
 		"This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
@@ -300,14 +306,14 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 	const gchar * translator_credits = _("translator_credits");
 
 	gtk_show_about_dialog (NULL,
-	                       "name", "GChemCalc",
+	                       "program-name", "GChemCalc",
 	                       "authors", authors,
 	                       "comments", comments,
 	                       "copyright", copyright,
 	                       "license", license,
 	                       "translator_credits", translator_credits,
 	                       "version", VERSION,
-	                       "website", "http://www.nongnu.org/gchemutils",
+	                       "website", "http://gchemutils.nongnu.org",
 	                       NULL);
 }
 
@@ -575,7 +581,7 @@ static void on_mode (GtkRadioAction *action, G_GNUC_UNUSED GtkRadioAction *curre
 	App->formula.SetParseMode (static_cast <FormulaParseMode> (gtk_radio_action_get_current_value (action)));
 }
 
-static void on_page (G_GNUC_UNUSED GtkNotebook *book, G_GNUC_UNUSED GtkNotebookPage *p, int page)
+static void on_page (G_GNUC_UNUSED GtkNotebook *book, G_GNUC_UNUSED void *p, int page)
 {
 	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (App->GetUIManager (), "/MainMenu/FileMenu/SaveAsImage"), page);
 	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (App->GetUIManager (), "/MainMenu/FileMenu/PageSetup"), page);
@@ -711,6 +717,7 @@ int main (int argc, char *argv[])
 
 	UIBuilder *builder = new UIBuilder (UIDIR"/gchemcalc.ui", GETTEXT_PACKAGE);
 	App->window = GTK_WINDOW (builder->GetRefdWidget ("gchemcalc"));
+	gtk_window_set_icon_name (App->window, App->GetIconName ().c_str ());
 	g_signal_connect (GTK_OBJECT (App->window), "destroy",
 		 G_CALLBACK (gtk_main_quit),
 		 NULL);
