@@ -4,7 +4,7 @@
  * GChemPaint
  * standaloneapp.cc
  *
- * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -50,7 +50,7 @@ void gcpStandaloneApp::OnFileNew(char const *Theme)
 
 GtkWindow* gcpStandaloneApp::GetWindow()
 {
-	return m_pActiveTarget->GetWindow ();
+	return (m_pActiveTarget)? m_pActiveTarget->GetWindow (): NULL;
 }
 
 void gcpStandaloneApp::NoMoreDocsEvent ()
