@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * programs/spectra/application.cc
  *
- * Copyright (C) 2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,6 +28,7 @@
 #include "view.h"
 #include "window.h"
 #include <gcu/filechooser.h>
+#include <gcu/loader.h>
 #include <glib/gi18n.h>
 #include <clocale>
 #include <map>
@@ -37,6 +38,21 @@ using namespace std;
 
 gsvApplication::gsvApplication (): Application (_("GSpectrum"), DATADIR, "gspectrum")
 {
+	// First, initialize plugins manager
+	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
+	gcu::Loader::Init (this);
+	m_SupportedMimeTypes.push_back ("chemical/x-jcamp-dx");
+	map<string, LoaderStruct>::iterator it;
+	bool found = Loader::GetFirstLoader (it);
+	while (found) {
+		if ((*it).second.supportsSpectra) {
+			if ((*it).second.read)
+				AddMimeType (m_SupportedMimeTypes, (*it).first);
+			if ((*it).second.write)
+				AddMimeType (m_WriteableMimeTypes, (*it).first);
+		}
+		found = Loader::GetNextLoader (it);
+	}
 	SetImageWidth (600);
 }
 
@@ -54,9 +70,7 @@ gsvDocument *gsvApplication::OnFileNew ()
 
 void gsvApplication::OnFileOpen (gsvDocument *Doc)
 {
-	list<string> l;
-	l.push_front ("chemical/x-jcamp-dx");
-	FileChooser (this, false, l, Doc);
+	FileChooser (this, false, m_SupportedMimeTypes, Doc);
 }
 
 void gsvApplication::OnQuit ()
@@ -79,7 +93,7 @@ bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 			char *unescaped = g_uri_unescape_string (filename, NULL);
 			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
 			g_free (unescaped);
-			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", message));
+			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gspectrum");
 			result = gtk_dialog_run (Box);
 			gtk_widget_destroy (GTK_WIDGET (Box));
@@ -91,17 +105,30 @@ bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		}
 		g_object_unref (file);
 	} else {
-		char *old_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
-		setlocale (LC_NUMERIC, "C");
 		if (pDoc && !pDoc->GetEmpty ())
 			pDoc = NULL;
 		if (!pDoc)
 			pDoc = OnFileNew ();
-		pDoc->Load (filename, mime_type);
-		setlocale (LC_NUMERIC, old_locale);
-		g_free (old_locale);
+		if (!strcmp (mime_type, "chemical/x-jcamp-dx"))
+			pDoc->Load (filename, mime_type);
+		else {
+			ContentType ctype = Load (filename, mime_type, pDoc);
+			if (ctype != gcu::ContentTypeSpectrum)
+				return false;
+		}
 		GtkRecentData data;
-		data.display_name = (char*) pDoc->GetTitle ().c_str ();
+		data.display_name = g_strdup (pDoc->GetTitle ().c_str ());
+		if (*data.display_name == 0) {
+			char *title = g_path_get_basename (filename);
+			char *buf = g_uri_unescape_string (title, NULL);
+			g_free (title);
+			data.display_name = buf;
+			pDoc->SetTitle (data.display_name);
+			g_free (buf);
+		}
+		char *dirname = g_path_get_dirname (filename);
+		SetCurDir (dirname);
+		g_free (dirname);
 		data.description = NULL;
 		data.mime_type = (char*) mime_type;
 		data.app_name = const_cast<char*> ("gspectrum");
@@ -109,6 +136,7 @@ bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		data.groups = NULL;
 		data.is_private =  FALSE;
 		gtk_recent_manager_add_full (GetRecentManager (), filename, &data);
+		g_free (data.display_name);
 	}
 	return false;
 }
@@ -132,3 +160,15 @@ void gsvApplication::OnSaveAsImage (gsvDocument *Doc)
 	l.push_front ("image/svg+xml");
 	FileChooser (this, true, l, Doc, _("Save as image"), GetImageSizeWidget ());
 }
+
+void gsvApplication::AddMimeType (list<string> &l, string const& mime_type)
+{
+	list<string>::iterator i, iend = l.end ();
+	for (i = l.begin (); i != iend; i++)
+		if (*i == mime_type)
+			break;
+	if (i == iend)
+		l.push_back (mime_type);
+	else
+		g_warning ("Duplicate mime type: %s", mime_type.c_str ());
+}
