@@ -136,14 +136,14 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, gsvWindow *Win)
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
 	gtk_show_about_dialog (NULL,
-	                       "name", "GSpectrum",
+	                       "program-name", "GSpectrum",
 	                       "authors", authors,
 	                       "comments", comments,
 	                       "copyright", copyright,
 	                       "license", license,
 	                       "translator_credits", translator_credits,
 	                       "version", VERSION,
-	                       "website", "http://www.nongnu.org/gchemutils",
+	                       "website", "http://gchemutils.nongnu.org",
 	                       NULL);
 }
 
@@ -171,7 +171,10 @@ static bool on_motion (GOGraphWidget *widget, GdkEventMotion *event, G_GNUC_UNUS
 	x_axis = GOG_AXIS (l->data);
 	g_slist_free (l);
 	l = gog_chart_get_axes (chart, GOG_AXIS_Y);
-	y_axis = GOG_AXIS (l->data);
+	// we need to use the first y axis, which comes last in the list, is this a kludge?
+	GSList *ptr;
+	for (ptr = l; ptr && ptr->next; ptr = ptr->next);
+	y_axis = GOG_AXIS (ptr->data);
 	g_slist_free (l);
     GogChartMap *map = gog_chart_map_new (chart,
             &(view->allocation), x_axis, y_axis, NULL, FALSE);
@@ -282,7 +285,10 @@ gsvWindow::gsvWindow (gsvApplication *App, gsvDocument *Doc)
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
 	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
-	gtk_recent_filter_add_mime_type (filter, "chemical/x-jcamp-dx");
+	std::list<std::string> &mime_types = App->GetSupportedMimeTypes ();
+	std::list<std::string>::iterator it, end = mime_types.end ();
+	for (it = mime_types.begin (); it != end; it++)
+		gtk_recent_filter_add_mime_type (filter, (*it).c_str ());
 	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (w), filter);
 	g_signal_connect (G_OBJECT (w), "item-activated", G_CALLBACK (on_recent), this);
 	GtkWidget *item = gtk_menu_item_new_with_label (_("Open recent"));
@@ -298,6 +304,7 @@ gsvWindow::gsvWindow (gsvApplication *App, gsvDocument *Doc)
 	g_signal_connect (G_OBJECT (w), "motion-notify-event", G_CALLBACK (on_motion), NULL);
 	gtk_container_add (GTK_CONTAINER (vbox), w);
 	gtk_widget_show_all (GTK_WIDGET (m_Window));
+	g_object_unref (ui_manager);
 	// Initialize print settings
 }
 
